package org.apache.axiom.om;
/*
 * Copyright 2004,2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.*;

import org.apache.axiom.om.*;

public class Tester {

    public static void main(String[] args) {


        OMFactory fac = OMAbstractFactory.getOMFactory();
        OMNamespace ns = fac.createOMNamespace("urn:foo", "");
        OMElement titleElem = fac.createOMElement("title", ns);
        OMNamespace ns2 = fac.createOMNamespace("urn:foo", "");
        OMElement childElem = fac.createOMElement("child", ns2);
        childElem.setText("boy");
        titleElem.addChild(childElem);
        String xml = titleElem.toString();
        // expect <title xmlns="urn:foo"><child>boy</child></title>
        System.out.println("xml = " + xml);

        // add attribute id="2"
        OMNamespace idNs = fac.createOMNamespace("", "");
        OMAttribute attr = fac.createOMAttribute("id", idNs, "2");
        childElem.addAttribute(attr);
        xml = titleElem.toString();
        // expect <title xmlns="urn:foo"><child id="2">boy</child></title>
        System.out.println("xml 2 = " + xml);

        OMOutputFormat format = new OMOutputFormat();
        String charSetEnc = "UTF-8";
        format.setCharSetEncoding(charSetEnc);
        format.setSOAP11(true);
        format.setDoOptimize(false);

        try {
            ByteArrayOutputStream bytesOut = new ByteArrayOutputStream();
            titleElem.serializeAndConsume(bytesOut, format);
            xml = new String(bytesOut.toByteArray());
            // expect <title xmlns="urn:foo"><child id="2">boy</child></title>
            System.out.println("xml 3 = " + xml);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }
}
